pub type IEnumSpObjectTokens = *mut ::core::ffi::c_void;
pub type ISpAudio = *mut ::core::ffi::c_void;
pub type ISpContainerLexicon = *mut ::core::ffi::c_void;
pub type ISpDataKey = *mut ::core::ffi::c_void;
pub type ISpDisplayAlternates = *mut ::core::ffi::c_void;
pub type ISpEnginePronunciation = *mut ::core::ffi::c_void;
pub type ISpEventSink = *mut ::core::ffi::c_void;
pub type ISpEventSource = *mut ::core::ffi::c_void;
pub type ISpEventSource2 = *mut ::core::ffi::c_void;
pub type ISpGrammarBuilder = *mut ::core::ffi::c_void;
pub type ISpGrammarBuilder2 = *mut ::core::ffi::c_void;
pub type ISpLexicon = *mut ::core::ffi::c_void;
pub type ISpMMSysAudio = *mut ::core::ffi::c_void;
pub type ISpNotifyCallback = *mut ::core::ffi::c_void;
pub type ISpNotifySink = *mut ::core::ffi::c_void;
pub type ISpNotifySource = *mut ::core::ffi::c_void;
pub type ISpNotifyTranslator = *mut ::core::ffi::c_void;
pub type ISpObjectToken = *mut ::core::ffi::c_void;
pub type ISpObjectTokenCategory = *mut ::core::ffi::c_void;
pub type ISpObjectTokenInit = *mut ::core::ffi::c_void;
pub type ISpObjectWithToken = *mut ::core::ffi::c_void;
pub type ISpPhoneConverter = *mut ::core::ffi::c_void;
pub type ISpPhoneticAlphabetConverter = *mut ::core::ffi::c_void;
pub type ISpPhoneticAlphabetSelection = *mut ::core::ffi::c_void;
pub type ISpPhrase = *mut ::core::ffi::c_void;
pub type ISpPhrase2 = *mut ::core::ffi::c_void;
pub type ISpPhraseAlt = *mut ::core::ffi::c_void;
pub type ISpProperties = *mut ::core::ffi::c_void;
pub type ISpRecoContext = *mut ::core::ffi::c_void;
pub type ISpRecoContext2 = *mut ::core::ffi::c_void;
pub type ISpRecoGrammar = *mut ::core::ffi::c_void;
pub type ISpRecoGrammar2 = *mut ::core::ffi::c_void;
pub type ISpRecoResult = *mut ::core::ffi::c_void;
pub type ISpRecoResult2 = *mut ::core::ffi::c_void;
pub type ISpRecognizer = *mut ::core::ffi::c_void;
pub type ISpRecognizer2 = *mut ::core::ffi::c_void;
pub type ISpRegDataKey = *mut ::core::ffi::c_void;
pub type ISpResourceManager = *mut ::core::ffi::c_void;
pub type ISpSerializeState = *mut ::core::ffi::c_void;
pub type ISpShortcut = *mut ::core::ffi::c_void;
pub type ISpStream = *mut ::core::ffi::c_void;
pub type ISpStreamFormat = *mut ::core::ffi::c_void;
pub type ISpStreamFormatConverter = *mut ::core::ffi::c_void;
pub type ISpTranscript = *mut ::core::ffi::c_void;
pub type ISpVoice = *mut ::core::ffi::c_void;
pub type ISpXMLRecoResult = *mut ::core::ffi::c_void;
pub type ISpeechAudio = *mut ::core::ffi::c_void;
pub type ISpeechAudioBufferInfo = *mut ::core::ffi::c_void;
pub type ISpeechAudioFormat = *mut ::core::ffi::c_void;
pub type ISpeechAudioStatus = *mut ::core::ffi::c_void;
pub type ISpeechBaseStream = *mut ::core::ffi::c_void;
pub type ISpeechCustomStream = *mut ::core::ffi::c_void;
pub type ISpeechDataKey = *mut ::core::ffi::c_void;
pub type ISpeechFileStream = *mut ::core::ffi::c_void;
pub type ISpeechGrammarRule = *mut ::core::ffi::c_void;
pub type ISpeechGrammarRuleState = *mut ::core::ffi::c_void;
pub type ISpeechGrammarRuleStateTransition = *mut ::core::ffi::c_void;
pub type ISpeechGrammarRuleStateTransitions = *mut ::core::ffi::c_void;
pub type ISpeechGrammarRules = *mut ::core::ffi::c_void;
pub type ISpeechLexicon = *mut ::core::ffi::c_void;
pub type ISpeechLexiconPronunciation = *mut ::core::ffi::c_void;
pub type ISpeechLexiconPronunciations = *mut ::core::ffi::c_void;
pub type ISpeechLexiconWord = *mut ::core::ffi::c_void;
pub type ISpeechLexiconWords = *mut ::core::ffi::c_void;
pub type ISpeechMMSysAudio = *mut ::core::ffi::c_void;
pub type ISpeechMemoryStream = *mut ::core::ffi::c_void;
pub type ISpeechObjectToken = *mut ::core::ffi::c_void;
pub type ISpeechObjectTokenCategory = *mut ::core::ffi::c_void;
pub type ISpeechObjectTokens = *mut ::core::ffi::c_void;
pub type ISpeechPhoneConverter = *mut ::core::ffi::c_void;
pub type ISpeechPhraseAlternate = *mut ::core::ffi::c_void;
pub type ISpeechPhraseAlternates = *mut ::core::ffi::c_void;
pub type ISpeechPhraseElement = *mut ::core::ffi::c_void;
pub type ISpeechPhraseElements = *mut ::core::ffi::c_void;
pub type ISpeechPhraseInfo = *mut ::core::ffi::c_void;
pub type ISpeechPhraseInfoBuilder = *mut ::core::ffi::c_void;
pub type ISpeechPhraseProperties = *mut ::core::ffi::c_void;
pub type ISpeechPhraseProperty = *mut ::core::ffi::c_void;
pub type ISpeechPhraseReplacement = *mut ::core::ffi::c_void;
pub type ISpeechPhraseReplacements = *mut ::core::ffi::c_void;
pub type ISpeechPhraseRule = *mut ::core::ffi::c_void;
pub type ISpeechPhraseRules = *mut ::core::ffi::c_void;
pub type ISpeechRecoContext = *mut ::core::ffi::c_void;
pub type ISpeechRecoGrammar = *mut ::core::ffi::c_void;
pub type ISpeechRecoResult = *mut ::core::ffi::c_void;
pub type ISpeechRecoResult2 = *mut ::core::ffi::c_void;
pub type ISpeechRecoResultDispatch = *mut ::core::ffi::c_void;
pub type ISpeechRecoResultTimes = *mut ::core::ffi::c_void;
pub type ISpeechRecognizer = *mut ::core::ffi::c_void;
pub type ISpeechRecognizerStatus = *mut ::core::ffi::c_void;
pub type ISpeechResourceLoader = *mut ::core::ffi::c_void;
pub type ISpeechTextSelectionInformation = *mut ::core::ffi::c_void;
pub type ISpeechVoice = *mut ::core::ffi::c_void;
pub type ISpeechVoiceStatus = *mut ::core::ffi::c_void;
pub type ISpeechWaveFormatEx = *mut ::core::ffi::c_void;
pub type ISpeechXMLRecoResult = *mut ::core::ffi::c_void;
pub type _ISpeechRecoContextEvents = *mut ::core::ffi::c_void;
pub type _ISpeechVoiceEvents = *mut ::core::ffi::c_void;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DEFAULT_WEIGHT: u32 = 1u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAPI_ERROR_BASE: u32 = 20480u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPALTERNATESCLSID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AlternatesCLSID");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCAT_APPLEXICONS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\AppLexicons");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCAT_AUDIOIN: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\AudioInput");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCAT_AUDIOOUT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\AudioOutput");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCAT_PHONECONVERTERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\PhoneConverters");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCAT_RECOGNIZERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\Recognizers");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCAT_RECOPROFILES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_CURRENT_USER\\SOFTWARE\\Microsoft\\Speech\\RecoProfiles");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCAT_TEXTNORMALIZERS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\TextNormalizers");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCAT_VOICES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\Voices");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCURRENT_USER_LEXICON_TOKEN_ID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_CURRENT_USER\\SOFTWARE\\Microsoft\\Speech\\CurrentUserLexicon");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCURRENT_USER_SHORTCUT_TOKEN_ID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_CURRENT_USER\\SOFTWARE\\Microsoft\\Speech\\CurrentUserShortcut");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDICTATION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("*");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_AddRemoveWord: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AddRemoveWord");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_AudioProperties: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AudioProperties");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_AudioVolume: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AudioVolume");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_EngineProperties: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("EngineProperties");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_MicTraining: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("MicTraining");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_RecoProfileProperties: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RecoProfileProperties");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_ShareData: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ShareData");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_Tutorial: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Tutorial");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_UserEnrollment: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UserEnrollment");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDUI_UserTraining: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UserTraining");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINFDICTATION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("*+");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPMMSYS_AUDIO_IN_TOKEN_ID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\AudioInput\\TokenEnums\\MMAudioIn\\");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPMMSYS_AUDIO_OUT_TOKEN_ID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\AudioOutput\\TokenEnums\\MMAudioOut\\");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_ADAPTATION_ON: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("AdaptationOn");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_COMPLEX_RESPONSE_SPEED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ComplexResponseSpeed");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_HIGH_CONFIDENCE_THRESHOLD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HighConfidenceThreshold");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_LOW_CONFIDENCE_THRESHOLD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LowConfidenceThreshold");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_NORMAL_CONFIDENCE_THRESHOLD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("NormalConfidenceThreshold");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_PERSISTED_BACKGROUND_ADAPTATION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PersistedBackgroundAdaptation");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_PERSISTED_LANGUAGE_MODEL_ADAPTATION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("PersistedLanguageModelAdaptation");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_RESOURCE_USAGE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ResourceUsage");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_RESPONSE_SPEED: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("ResponseSpeed");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPROP_UX_IS_LISTENING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UXIsListening");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRECOEXTENSION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("RecoExtension");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREG_LOCAL_MACHINE_ROOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREG_SAFE_USER_TOKENS: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_LOCAL_MACHINE\\SOFTWARE\\Microsoft\\Speech\\UserTokens");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREG_USER_ROOT: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("HKEY_CURRENT_USER\\SOFTWARE\\Microsoft\\Speech");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRP_NORMAL: u32 = 0u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOKENKEY_ATTRIBUTES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Attributes");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOKENKEY_AUDIO_LATENCY_TRUNCATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LatencyTruncateThreshold");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOKENKEY_AUDIO_LATENCY_UPDATE_INTERVAL: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LatencyUpdateInterval");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOKENKEY_AUDIO_LATENCY_WARNING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("LatencyWarningThreshold");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOKENKEY_FILES: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Files");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOKENKEY_RETAINEDAUDIO: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("SecondsPerRetainedAudioEvent");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOKENKEY_UI: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("UI");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOKENVALUE_CLSID: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("CLSID");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPTOPIC_SPELLING: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Spelling");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVOICECATEGORY_TTSRATE: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("DefaultTTSRate");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWILDCARD: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("...");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_EMULATE_RESULT: u32 = 1073741824u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_LOW_CONFIDENCE: i32 = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_MAX_LANGIDS: u32 = 20u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_MAX_PRON_LENGTH: u32 = 384u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_MAX_WORD_LENGTH: u32 = 128u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_NORMAL_CONFIDENCE: u32 = 0u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_STREAMPOS_ASAP: u32 = 0u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_STREAMPOS_REALTIME: i32 = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SR_LOCALIZED_DESCRIPTION: ::windows_sys::core::PCWSTR = ::windows_sys::core::w!("Description");
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpAudioFormat: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x9ef96870_e160_4792_820d_48cf0649e4ec);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpCompressedLexicon: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x90903716_2f42_11d3_9c26_00c04f8ef87c);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpCustomStream: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x8dbef13f_1948_4aa8_8cf0_048eebed95d8);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpFileStream: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x947812b3_2ae1_4644_ba86_9e90ded7ec91);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpInProcRecoContext: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x73ad6842_ace0_45e8_a4dd_8795881a2c2a);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpInprocRecognizer: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x41b89b6b_9399_11d2_9623_00c04f8ee628);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpLexicon: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x0655e396_25d0_11d3_9c26_00c04f8ef87c);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpMMAudioEnum: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xab1890a0_e91f_11d2_bb91_00c04f8ee6c0);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpMMAudioIn: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xcf3d2e50_53f2_11d2_960c_00c04f8ee628);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpMMAudioOut: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xa8c680eb_3d32_11d2_9ee7_00c04f797396);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpMemoryStream: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x5fb7ef7d_dff4_468a_b6b7_2fcbd188f994);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpNotifyTranslator: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xe2ae5372_5d40_11d2_960e_00c04f8ee628);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpNullPhoneConverter: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x455f24e9_7396_4a16_9715_7c0fdbe3efe3);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpObjectToken: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xef411752_3736_4cb4_9c8c_8ef4ccb58efe);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpObjectTokenCategory: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xa910187f_0c7a_45ac_92cc_59edafb77b53);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpPhoneConverter: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x9185f743_1143_4c28_86b5_bff14f20e5c8);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpPhoneticAlphabetConverter: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x4f414126_dfe3_4629_99ee_797978317ead);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpPhraseInfoBuilder: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xc23fc28d_c55f_4720_8b32_91f73c2bd5d1);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpResourceManager: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x96749373_3391_11d2_9ee3_00c04f797396);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpSharedRecoContext: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x47206204_5eca_11d2_960f_00c04f8ee628);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpSharedRecognizer: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x3bee4890_4fe9_4a37_8c1e_5e7e12791c1f);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpShortcut: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x0d722f1a_9fcf_4e62_96d8_6df8f01a26aa);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpStream: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x715d9c59_4442_11d2_9605_00c04f8ee628);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpStreamFormatConverter: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x7013943a_e2ec_11d2_a086_00c04f8ef9b5);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpTextSelectionInformation: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x0f92030a_cbfd_4ab8_a164_ff5985547ff6);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpUnCompressedLexicon: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xc9e37c15_df92_4727_85d6_72e5eeb6995a);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpVoice: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0x96749377_3391_11d2_9ee3_00c04f797396);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpWaveFormatEx: ::windows_sys::core::GUID = ::windows_sys::core::GUID::from_u128(0xc79a574c_63be_44b9_801f_283f87f898be);
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SpeechAllElements: i32 = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const Speech_Default_Weight: f32 = 1f32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const Speech_Max_Pron_Length: i32 = 384i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const Speech_Max_Word_Length: i32 = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const Speech_StreamPos_Asap: i32 = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const Speech_StreamPos_RealTime: i32 = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPIDSPRG = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGId: DISPIDSPRG = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGRecoContext: DISPIDSPRG = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGState: DISPIDSPRG = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGRules: DISPIDSPRG = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGReset: DISPIDSPRG = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGCommit: DISPIDSPRG = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGCmdLoadFromFile: DISPIDSPRG = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGCmdLoadFromObject: DISPIDSPRG = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGCmdLoadFromResource: DISPIDSPRG = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGCmdLoadFromMemory: DISPIDSPRG = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGCmdLoadFromProprietaryGrammar: DISPIDSPRG = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGCmdSetRuleState: DISPIDSPRG = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGCmdSetRuleIdState: DISPIDSPRG = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGDictationLoad: DISPIDSPRG = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGDictationUnload: DISPIDSPRG = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGDictationSetState: DISPIDSPRG = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGSetWordSequenceData: DISPIDSPRG = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGSetTextSelection: DISPIDSPRG = 18i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGIsPronounceable: DISPIDSPRG = 19i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPIDSPTSI = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPIDSPTSI_ActiveOffset: DISPIDSPTSI = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPIDSPTSI_ActiveLength: DISPIDSPTSI = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPIDSPTSI_SelectionOffset: DISPIDSPTSI = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPIDSPTSI_SelectionLength: DISPIDSPTSI = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechAudio = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SAStatus: DISPID_SpeechAudio = 200i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SABufferInfo: DISPID_SpeechAudio = 201i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SADefaultFormat: DISPID_SpeechAudio = 202i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SAVolume: DISPID_SpeechAudio = 203i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SABufferNotifySize: DISPID_SpeechAudio = 204i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SAEventHandle: DISPID_SpeechAudio = 205i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SASetState: DISPID_SpeechAudio = 206i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechAudioBufferInfo = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SABIMinNotification: DISPID_SpeechAudioBufferInfo = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SABIBufferSize: DISPID_SpeechAudioBufferInfo = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SABIEventBias: DISPID_SpeechAudioBufferInfo = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechAudioFormat = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SAFType: DISPID_SpeechAudioFormat = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SAFGuid: DISPID_SpeechAudioFormat = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SAFGetWaveFormatEx: DISPID_SpeechAudioFormat = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SAFSetWaveFormatEx: DISPID_SpeechAudioFormat = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechAudioStatus = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SASFreeBufferSpace: DISPID_SpeechAudioStatus = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SASNonBlockingIO: DISPID_SpeechAudioStatus = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SASState: DISPID_SpeechAudioStatus = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SASCurrentSeekPosition: DISPID_SpeechAudioStatus = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SASCurrentDevicePosition: DISPID_SpeechAudioStatus = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechBaseStream = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SBSFormat: DISPID_SpeechBaseStream = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SBSRead: DISPID_SpeechBaseStream = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SBSWrite: DISPID_SpeechBaseStream = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SBSSeek: DISPID_SpeechBaseStream = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechCustomStream = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SCSBaseStream: DISPID_SpeechCustomStream = 100i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechDataKey = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKSetBinaryValue: DISPID_SpeechDataKey = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKGetBinaryValue: DISPID_SpeechDataKey = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKSetStringValue: DISPID_SpeechDataKey = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKGetStringValue: DISPID_SpeechDataKey = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKSetLongValue: DISPID_SpeechDataKey = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKGetlongValue: DISPID_SpeechDataKey = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKOpenKey: DISPID_SpeechDataKey = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKCreateKey: DISPID_SpeechDataKey = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKDeleteKey: DISPID_SpeechDataKey = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKDeleteValue: DISPID_SpeechDataKey = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKEnumKeys: DISPID_SpeechDataKey = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SDKEnumValues: DISPID_SpeechDataKey = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechFileStream = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SFSOpen: DISPID_SpeechFileStream = 100i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SFSClose: DISPID_SpeechFileStream = 101i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechGrammarRule = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRAttributes: DISPID_SpeechGrammarRule = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRInitialState: DISPID_SpeechGrammarRule = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRName: DISPID_SpeechGrammarRule = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRId: DISPID_SpeechGrammarRule = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRClear: DISPID_SpeechGrammarRule = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRAddResource: DISPID_SpeechGrammarRule = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRAddState: DISPID_SpeechGrammarRule = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechGrammarRuleState = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSRule: DISPID_SpeechGrammarRuleState = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTransitions: DISPID_SpeechGrammarRuleState = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSAddWordTransition: DISPID_SpeechGrammarRuleState = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSAddRuleTransition: DISPID_SpeechGrammarRuleState = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSAddSpecialTransition: DISPID_SpeechGrammarRuleState = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechGrammarRuleStateTransition = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTType: DISPID_SpeechGrammarRuleStateTransition = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTText: DISPID_SpeechGrammarRuleStateTransition = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTRule: DISPID_SpeechGrammarRuleStateTransition = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTWeight: DISPID_SpeechGrammarRuleStateTransition = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTPropertyName: DISPID_SpeechGrammarRuleStateTransition = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTPropertyId: DISPID_SpeechGrammarRuleStateTransition = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTPropertyValue: DISPID_SpeechGrammarRuleStateTransition = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTNextState: DISPID_SpeechGrammarRuleStateTransition = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechGrammarRuleStateTransitions = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTsCount: DISPID_SpeechGrammarRuleStateTransitions = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTsItem: DISPID_SpeechGrammarRuleStateTransitions = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRSTs_NewEnum: DISPID_SpeechGrammarRuleStateTransitions = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechGrammarRules = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRsCount: DISPID_SpeechGrammarRules = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRsDynamic: DISPID_SpeechGrammarRules = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRsAdd: DISPID_SpeechGrammarRules = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRsCommit: DISPID_SpeechGrammarRules = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRsCommitAndSave: DISPID_SpeechGrammarRules = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRsFindRule: DISPID_SpeechGrammarRules = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRsItem: DISPID_SpeechGrammarRules = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SGRs_NewEnum: DISPID_SpeechGrammarRules = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechLexicon = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLGenerationId: DISPID_SpeechLexicon = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLGetWords: DISPID_SpeechLexicon = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLAddPronunciation: DISPID_SpeechLexicon = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLAddPronunciationByPhoneIds: DISPID_SpeechLexicon = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLRemovePronunciation: DISPID_SpeechLexicon = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLRemovePronunciationByPhoneIds: DISPID_SpeechLexicon = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLGetPronunciations: DISPID_SpeechLexicon = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLGetGenerationChange: DISPID_SpeechLexicon = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechLexiconProns = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLPsCount: DISPID_SpeechLexiconProns = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLPsItem: DISPID_SpeechLexiconProns = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLPs_NewEnum: DISPID_SpeechLexiconProns = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechLexiconPronunciation = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLPType: DISPID_SpeechLexiconPronunciation = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLPLangId: DISPID_SpeechLexiconPronunciation = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLPPartOfSpeech: DISPID_SpeechLexiconPronunciation = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLPPhoneIds: DISPID_SpeechLexiconPronunciation = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLPSymbolic: DISPID_SpeechLexiconPronunciation = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechLexiconWord = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLWLangId: DISPID_SpeechLexiconWord = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLWType: DISPID_SpeechLexiconWord = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLWWord: DISPID_SpeechLexiconWord = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLWPronunciations: DISPID_SpeechLexiconWord = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechLexiconWords = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLWsCount: DISPID_SpeechLexiconWords = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLWsItem: DISPID_SpeechLexiconWords = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SLWs_NewEnum: DISPID_SpeechLexiconWords = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechMMSysAudio = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SMSADeviceId: DISPID_SpeechMMSysAudio = 300i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SMSALineId: DISPID_SpeechMMSysAudio = 301i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SMSAMMHandle: DISPID_SpeechMMSysAudio = 302i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechMemoryStream = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SMSSetData: DISPID_SpeechMemoryStream = 100i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SMSGetData: DISPID_SpeechMemoryStream = 101i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechObjectToken = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTId: DISPID_SpeechObjectToken = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTDataKey: DISPID_SpeechObjectToken = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTCategory: DISPID_SpeechObjectToken = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTGetDescription: DISPID_SpeechObjectToken = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTSetId: DISPID_SpeechObjectToken = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTGetAttribute: DISPID_SpeechObjectToken = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTCreateInstance: DISPID_SpeechObjectToken = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTRemove: DISPID_SpeechObjectToken = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTGetStorageFileName: DISPID_SpeechObjectToken = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTRemoveStorageFileName: DISPID_SpeechObjectToken = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTIsUISupported: DISPID_SpeechObjectToken = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTDisplayUI: DISPID_SpeechObjectToken = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTMatchesAttributes: DISPID_SpeechObjectToken = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechObjectTokenCategory = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTCId: DISPID_SpeechObjectTokenCategory = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTCDefault: DISPID_SpeechObjectTokenCategory = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTCSetId: DISPID_SpeechObjectTokenCategory = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTCGetDataKey: DISPID_SpeechObjectTokenCategory = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTCEnumerateTokens: DISPID_SpeechObjectTokenCategory = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechObjectTokens = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTsCount: DISPID_SpeechObjectTokens = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTsItem: DISPID_SpeechObjectTokens = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SOTs_NewEnum: DISPID_SpeechObjectTokens = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhoneConverter = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPCLangId: DISPID_SpeechPhoneConverter = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPCPhoneToId: DISPID_SpeechPhoneConverter = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPCIdToPhone: DISPID_SpeechPhoneConverter = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseAlternate = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPARecoResult: DISPID_SpeechPhraseAlternate = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPAStartElementInResult: DISPID_SpeechPhraseAlternate = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPANumberOfElementsInResult: DISPID_SpeechPhraseAlternate = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPAPhraseInfo: DISPID_SpeechPhraseAlternate = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPACommit: DISPID_SpeechPhraseAlternate = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseAlternates = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPAsCount: DISPID_SpeechPhraseAlternates = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPAsItem: DISPID_SpeechPhraseAlternates = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPAs_NewEnum: DISPID_SpeechPhraseAlternates = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseBuilder = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPBRestorePhraseFromMemory: DISPID_SpeechPhraseBuilder = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseElement = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEAudioTimeOffset: DISPID_SpeechPhraseElement = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEAudioSizeTime: DISPID_SpeechPhraseElement = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEAudioStreamOffset: DISPID_SpeechPhraseElement = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEAudioSizeBytes: DISPID_SpeechPhraseElement = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPERetainedStreamOffset: DISPID_SpeechPhraseElement = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPERetainedSizeBytes: DISPID_SpeechPhraseElement = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEDisplayText: DISPID_SpeechPhraseElement = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPELexicalForm: DISPID_SpeechPhraseElement = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEPronunciation: DISPID_SpeechPhraseElement = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEDisplayAttributes: DISPID_SpeechPhraseElement = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPERequiredConfidence: DISPID_SpeechPhraseElement = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEActualConfidence: DISPID_SpeechPhraseElement = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEEngineConfidence: DISPID_SpeechPhraseElement = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseElements = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEsCount: DISPID_SpeechPhraseElements = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEsItem: DISPID_SpeechPhraseElements = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPEs_NewEnum: DISPID_SpeechPhraseElements = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseInfo = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPILanguageId: DISPID_SpeechPhraseInfo = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIGrammarId: DISPID_SpeechPhraseInfo = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIStartTime: DISPID_SpeechPhraseInfo = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIAudioStreamPosition: DISPID_SpeechPhraseInfo = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIAudioSizeBytes: DISPID_SpeechPhraseInfo = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIRetainedSizeBytes: DISPID_SpeechPhraseInfo = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIAudioSizeTime: DISPID_SpeechPhraseInfo = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIRule: DISPID_SpeechPhraseInfo = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIProperties: DISPID_SpeechPhraseInfo = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIElements: DISPID_SpeechPhraseInfo = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIReplacements: DISPID_SpeechPhraseInfo = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIEngineId: DISPID_SpeechPhraseInfo = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIEnginePrivateData: DISPID_SpeechPhraseInfo = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPISaveToMemory: DISPID_SpeechPhraseInfo = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIGetText: DISPID_SpeechPhraseInfo = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPIGetDisplayAttributes: DISPID_SpeechPhraseInfo = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseProperties = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPsCount: DISPID_SpeechPhraseProperties = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPsItem: DISPID_SpeechPhraseProperties = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPs_NewEnum: DISPID_SpeechPhraseProperties = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseProperty = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPName: DISPID_SpeechPhraseProperty = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPId: DISPID_SpeechPhraseProperty = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPValue: DISPID_SpeechPhraseProperty = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPFirstElement: DISPID_SpeechPhraseProperty = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPNumberOfElements: DISPID_SpeechPhraseProperty = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPEngineConfidence: DISPID_SpeechPhraseProperty = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPConfidence: DISPID_SpeechPhraseProperty = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPParent: DISPID_SpeechPhraseProperty = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPPChildren: DISPID_SpeechPhraseProperty = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseReplacement = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRDisplayAttributes: DISPID_SpeechPhraseReplacement = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRText: DISPID_SpeechPhraseReplacement = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRFirstElement: DISPID_SpeechPhraseReplacement = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRNumberOfElements: DISPID_SpeechPhraseReplacement = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseReplacements = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRsCount: DISPID_SpeechPhraseReplacements = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRsItem: DISPID_SpeechPhraseReplacements = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRs_NewEnum: DISPID_SpeechPhraseReplacements = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseRule = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRuleName: DISPID_SpeechPhraseRule = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRuleId: DISPID_SpeechPhraseRule = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRuleFirstElement: DISPID_SpeechPhraseRule = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRuleNumberOfElements: DISPID_SpeechPhraseRule = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRuleParent: DISPID_SpeechPhraseRule = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRuleChildren: DISPID_SpeechPhraseRule = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRuleConfidence: DISPID_SpeechPhraseRule = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRuleEngineConfidence: DISPID_SpeechPhraseRule = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechPhraseRules = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRulesCount: DISPID_SpeechPhraseRules = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRulesItem: DISPID_SpeechPhraseRules = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SPRules_NewEnum: DISPID_SpeechPhraseRules = -4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechRecoContext = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCRecognizer: DISPID_SpeechRecoContext = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCAudioInInterferenceStatus: DISPID_SpeechRecoContext = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCRequestedUIType: DISPID_SpeechRecoContext = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCVoice: DISPID_SpeechRecoContext = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRAllowVoiceFormatMatchingOnNextSet: DISPID_SpeechRecoContext = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCVoicePurgeEvent: DISPID_SpeechRecoContext = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEventInterests: DISPID_SpeechRecoContext = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCCmdMaxAlternates: DISPID_SpeechRecoContext = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCState: DISPID_SpeechRecoContext = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCRetainedAudio: DISPID_SpeechRecoContext = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCRetainedAudioFormat: DISPID_SpeechRecoContext = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCPause: DISPID_SpeechRecoContext = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCResume: DISPID_SpeechRecoContext = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCCreateGrammar: DISPID_SpeechRecoContext = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCCreateResultFromMemory: DISPID_SpeechRecoContext = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCBookmark: DISPID_SpeechRecoContext = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCSetAdaptationData: DISPID_SpeechRecoContext = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechRecoContextEvents = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEStartStream: DISPID_SpeechRecoContextEvents = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEEndStream: DISPID_SpeechRecoContextEvents = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEBookmark: DISPID_SpeechRecoContextEvents = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCESoundStart: DISPID_SpeechRecoContextEvents = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCESoundEnd: DISPID_SpeechRecoContextEvents = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEPhraseStart: DISPID_SpeechRecoContextEvents = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCERecognition: DISPID_SpeechRecoContextEvents = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEHypothesis: DISPID_SpeechRecoContextEvents = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEPropertyNumberChange: DISPID_SpeechRecoContextEvents = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEPropertyStringChange: DISPID_SpeechRecoContextEvents = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEFalseRecognition: DISPID_SpeechRecoContextEvents = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEInterference: DISPID_SpeechRecoContextEvents = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCERequestUI: DISPID_SpeechRecoContextEvents = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCERecognizerStateChange: DISPID_SpeechRecoContextEvents = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEAdaptation: DISPID_SpeechRecoContextEvents = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCERecognitionForOtherContext: DISPID_SpeechRecoContextEvents = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEAudioLevel: DISPID_SpeechRecoContextEvents = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCEEnginePrivate: DISPID_SpeechRecoContextEvents = 18i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechRecoResult = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRRecoContext: DISPID_SpeechRecoResult = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRTimes: DISPID_SpeechRecoResult = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRAudioFormat: DISPID_SpeechRecoResult = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRPhraseInfo: DISPID_SpeechRecoResult = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRAlternates: DISPID_SpeechRecoResult = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRAudio: DISPID_SpeechRecoResult = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRSpeakAudio: DISPID_SpeechRecoResult = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRSaveToMemory: DISPID_SpeechRecoResult = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRDiscardResultInfo: DISPID_SpeechRecoResult = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechRecoResult2 = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRSetTextFeedback: DISPID_SpeechRecoResult2 = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechRecoResultTimes = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRTStreamTime: DISPID_SpeechRecoResultTimes = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRTLength: DISPID_SpeechRecoResultTimes = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRTTickCount: DISPID_SpeechRecoResultTimes = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRTOffsetFromStart: DISPID_SpeechRecoResultTimes = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechRecognizer = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRecognizer: DISPID_SpeechRecognizer = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRAllowAudioInputFormatChangesOnNextSet: DISPID_SpeechRecognizer = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRAudioInput: DISPID_SpeechRecognizer = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRAudioInputStream: DISPID_SpeechRecognizer = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRIsShared: DISPID_SpeechRecognizer = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRState: DISPID_SpeechRecognizer = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRStatus: DISPID_SpeechRecognizer = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRProfile: DISPID_SpeechRecognizer = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SREmulateRecognition: DISPID_SpeechRecognizer = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRCreateRecoContext: DISPID_SpeechRecognizer = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGetFormat: DISPID_SpeechRecognizer = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRSetPropertyNumber: DISPID_SpeechRecognizer = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGetPropertyNumber: DISPID_SpeechRecognizer = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRSetPropertyString: DISPID_SpeechRecognizer = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGetPropertyString: DISPID_SpeechRecognizer = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRIsUISupported: DISPID_SpeechRecognizer = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRDisplayUI: DISPID_SpeechRecognizer = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRGetRecognizers: DISPID_SpeechRecognizer = 18i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVGetAudioInputs: DISPID_SpeechRecognizer = 19i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVGetProfiles: DISPID_SpeechRecognizer = 20i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechRecognizerStatus = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRSAudioStatus: DISPID_SpeechRecognizerStatus = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRSCurrentStreamPosition: DISPID_SpeechRecognizerStatus = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRSCurrentStreamNumber: DISPID_SpeechRecognizerStatus = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRSNumberOfActiveRules: DISPID_SpeechRecognizerStatus = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRSClsidEngine: DISPID_SpeechRecognizerStatus = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRSSupportedLanguages: DISPID_SpeechRecognizerStatus = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechVoice = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVStatus: DISPID_SpeechVoice = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVVoice: DISPID_SpeechVoice = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVAudioOutput: DISPID_SpeechVoice = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVAudioOutputStream: DISPID_SpeechVoice = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVRate: DISPID_SpeechVoice = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVVolume: DISPID_SpeechVoice = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVAllowAudioOuputFormatChangesOnNextSet: DISPID_SpeechVoice = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEventInterests: DISPID_SpeechVoice = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVPriority: DISPID_SpeechVoice = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVAlertBoundary: DISPID_SpeechVoice = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSyncronousSpeakTimeout: DISPID_SpeechVoice = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSpeak: DISPID_SpeechVoice = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSpeakStream: DISPID_SpeechVoice = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVPause: DISPID_SpeechVoice = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVResume: DISPID_SpeechVoice = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSkip: DISPID_SpeechVoice = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVGetVoices: DISPID_SpeechVoice = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVGetAudioOutputs: DISPID_SpeechVoice = 18i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVWaitUntilDone: DISPID_SpeechVoice = 19i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSpeakCompleteEvent: DISPID_SpeechVoice = 20i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVIsUISupported: DISPID_SpeechVoice = 21i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVDisplayUI: DISPID_SpeechVoice = 22i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechVoiceEvent = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEStreamStart: DISPID_SpeechVoiceEvent = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEStreamEnd: DISPID_SpeechVoiceEvent = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEVoiceChange: DISPID_SpeechVoiceEvent = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEBookmark: DISPID_SpeechVoiceEvent = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEWord: DISPID_SpeechVoiceEvent = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEPhoneme: DISPID_SpeechVoiceEvent = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVESentenceBoundary: DISPID_SpeechVoiceEvent = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEViseme: DISPID_SpeechVoiceEvent = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEAudioLevel: DISPID_SpeechVoiceEvent = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVEEnginePrivate: DISPID_SpeechVoiceEvent = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechVoiceStatus = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSCurrentStreamNumber: DISPID_SpeechVoiceStatus = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSLastStreamNumberQueued: DISPID_SpeechVoiceStatus = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSLastResult: DISPID_SpeechVoiceStatus = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSRunningState: DISPID_SpeechVoiceStatus = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSInputWordPosition: DISPID_SpeechVoiceStatus = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSInputWordLength: DISPID_SpeechVoiceStatus = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSInputSentencePosition: DISPID_SpeechVoiceStatus = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSInputSentenceLength: DISPID_SpeechVoiceStatus = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSLastBookmark: DISPID_SpeechVoiceStatus = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSLastBookmarkId: DISPID_SpeechVoiceStatus = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSPhonemeId: DISPID_SpeechVoiceStatus = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SVSVisemeId: DISPID_SpeechVoiceStatus = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechWaveFormatEx = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SWFEFormatTag: DISPID_SpeechWaveFormatEx = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SWFEChannels: DISPID_SpeechWaveFormatEx = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SWFESamplesPerSec: DISPID_SpeechWaveFormatEx = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SWFEAvgBytesPerSec: DISPID_SpeechWaveFormatEx = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SWFEBlockAlign: DISPID_SpeechWaveFormatEx = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SWFEBitsPerSample: DISPID_SpeechWaveFormatEx = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SWFEExtraData: DISPID_SpeechWaveFormatEx = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type DISPID_SpeechXMLRecoResult = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRGetXMLResult: DISPID_SpeechXMLRecoResult = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const DISPID_SRRGetXMLErrorInfo: DISPID_SpeechXMLRecoResult = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type PHONETICALPHABET = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const PA_Ipa: PHONETICALPHABET = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const PA_Ups: PHONETICALPHABET = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const PA_Sapi: PHONETICALPHABET = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPADAPTATIONRELEVANCE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAR_Unknown: SPADAPTATIONRELEVANCE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAR_Low: SPADAPTATIONRELEVANCE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAR_Medium: SPADAPTATIONRELEVANCE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAR_High: SPADAPTATIONRELEVANCE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPADAPTATIONSETTINGS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPADS_Default: SPADAPTATIONSETTINGS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPADS_CurrentRecognizer: SPADAPTATIONSETTINGS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPADS_RecoProfile: SPADAPTATIONSETTINGS = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPADS_Immediate: SPADAPTATIONSETTINGS = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPADS_Reset: SPADAPTATIONSETTINGS = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPADS_HighVolumeDataSource: SPADAPTATIONSETTINGS = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPAUDIOOPTIONS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAO_NONE: SPAUDIOOPTIONS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAO_RETAIN_AUDIO: SPAUDIOOPTIONS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPAUDIOSTATE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAS_CLOSED: SPAUDIOSTATE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAS_STOP: SPAUDIOSTATE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAS_PAUSE: SPAUDIOSTATE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAS_RUN: SPAUDIOSTATE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPBOOKMARKOPTIONS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPBO_NONE: SPBOOKMARKOPTIONS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPBO_PAUSE: SPBOOKMARKOPTIONS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPBO_AHEAD: SPBOOKMARKOPTIONS = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPBO_TIME_UNITS: SPBOOKMARKOPTIONS = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPCFGRULEATTRIBUTES = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_TopLevel: SPCFGRULEATTRIBUTES = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_Active: SPCFGRULEATTRIBUTES = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_Export: SPCFGRULEATTRIBUTES = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_Import: SPCFGRULEATTRIBUTES = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_Interpreter: SPCFGRULEATTRIBUTES = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_Dynamic: SPCFGRULEATTRIBUTES = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_Root: SPCFGRULEATTRIBUTES = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_AutoPause: SPCFGRULEATTRIBUTES = 65536i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRAF_UserDelimited: SPCFGRULEATTRIBUTES = 131072i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPCOMMITFLAGS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCF_NONE: SPCOMMITFLAGS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCF_ADD_TO_USER_LEXICON: SPCOMMITFLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCF_DEFINITE_CORRECTION: SPCOMMITFLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPCONTEXTSTATE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCS_DISABLED: SPCONTEXTSTATE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPCS_ENABLED: SPCONTEXTSTATE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPDATAKEYLOCATION = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDKL_DefaultLocation: SPDATAKEYLOCATION = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDKL_CurrentUser: SPDATAKEYLOCATION = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDKL_LocalMachine: SPDATAKEYLOCATION = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDKL_CurrentConfig: SPDATAKEYLOCATION = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPDISPLAYATTRIBUTES = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAF_ONE_TRAILING_SPACE: SPDISPLAYATTRIBUTES = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAF_TWO_TRAILING_SPACES: SPDISPLAYATTRIBUTES = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAF_CONSUME_LEADING_SPACES: SPDISPLAYATTRIBUTES = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAF_BUFFER_POSITION: SPDISPLAYATTRIBUTES = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAF_ALL: SPDISPLAYATTRIBUTES = 31i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPAF_USER_SPECIFIED: SPDISPLAYATTRIBUTES = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPEAKFLAGS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_DEFAULT: SPEAKFLAGS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_ASYNC: SPEAKFLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_PURGEBEFORESPEAK: SPEAKFLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_IS_FILENAME: SPEAKFLAGS = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_IS_XML: SPEAKFLAGS = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_IS_NOT_XML: SPEAKFLAGS = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_PERSIST_XML: SPEAKFLAGS = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_NLP_SPEAK_PUNC: SPEAKFLAGS = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_PARSE_SAPI: SPEAKFLAGS = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_PARSE_SSML: SPEAKFLAGS = 256i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_PARSE_AUTODETECT: SPEAKFLAGS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_NLP_MASK: SPEAKFLAGS = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_PARSE_MASK: SPEAKFLAGS = 384i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_VOICE_MASK: SPEAKFLAGS = 511i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPF_UNUSED_FLAGS: SPEAKFLAGS = -512i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPENDSRSTREAMFLAGS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPESF_NONE: SPENDSRSTREAMFLAGS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPESF_STREAM_RELEASED: SPENDSRSTREAMFLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPESF_EMULATED: SPENDSRSTREAMFLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPEVENTENUM = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_UNDEFINED: SPEVENTENUM = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_START_INPUT_STREAM: SPEVENTENUM = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_END_INPUT_STREAM: SPEVENTENUM = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_VOICE_CHANGE: SPEVENTENUM = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_TTS_BOOKMARK: SPEVENTENUM = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_WORD_BOUNDARY: SPEVENTENUM = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_PHONEME: SPEVENTENUM = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_SENTENCE_BOUNDARY: SPEVENTENUM = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_VISEME: SPEVENTENUM = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_TTS_AUDIO_LEVEL: SPEVENTENUM = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_TTS_PRIVATE: SPEVENTENUM = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_MIN_TTS: SPEVENTENUM = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_MAX_TTS: SPEVENTENUM = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_END_SR_STREAM: SPEVENTENUM = 34i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_SOUND_START: SPEVENTENUM = 35i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_SOUND_END: SPEVENTENUM = 36i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_PHRASE_START: SPEVENTENUM = 37i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RECOGNITION: SPEVENTENUM = 38i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_HYPOTHESIS: SPEVENTENUM = 39i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_SR_BOOKMARK: SPEVENTENUM = 40i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_PROPERTY_NUM_CHANGE: SPEVENTENUM = 41i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_PROPERTY_STRING_CHANGE: SPEVENTENUM = 42i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_FALSE_RECOGNITION: SPEVENTENUM = 43i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_INTERFERENCE: SPEVENTENUM = 44i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_REQUEST_UI: SPEVENTENUM = 45i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RECO_STATE_CHANGE: SPEVENTENUM = 46i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_ADAPTATION: SPEVENTENUM = 47i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_START_SR_STREAM: SPEVENTENUM = 48i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RECO_OTHER_CONTEXT: SPEVENTENUM = 49i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_SR_AUDIO_LEVEL: SPEVENTENUM = 50i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_SR_RETAINEDAUDIO: SPEVENTENUM = 51i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_SR_PRIVATE: SPEVENTENUM = 52i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RESERVED4: SPEVENTENUM = 53i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RESERVED5: SPEVENTENUM = 54i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RESERVED6: SPEVENTENUM = 55i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_MIN_SR: SPEVENTENUM = 34i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_MAX_SR: SPEVENTENUM = 55i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RESERVED1: SPEVENTENUM = 30i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RESERVED2: SPEVENTENUM = 33i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPEI_RESERVED3: SPEVENTENUM = 63i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPEVENTLPARAMTYPE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPET_LPARAM_IS_UNDEFINED: SPEVENTLPARAMTYPE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPET_LPARAM_IS_TOKEN: SPEVENTLPARAMTYPE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPET_LPARAM_IS_OBJECT: SPEVENTLPARAMTYPE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPET_LPARAM_IS_POINTER: SPEVENTLPARAMTYPE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPET_LPARAM_IS_STRING: SPEVENTLPARAMTYPE = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPFILEMODE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPFM_OPEN_READONLY: SPFILEMODE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPFM_OPEN_READWRITE: SPFILEMODE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPFM_CREATE: SPFILEMODE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPFM_CREATE_ALWAYS: SPFILEMODE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPFM_NUM_MODES: SPFILEMODE = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPGRAMMAROPTIONS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_SAPI: SPGRAMMAROPTIONS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_SRGS: SPGRAMMAROPTIONS = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_UPS: SPGRAMMAROPTIONS = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_SRGS_MS_SCRIPT: SPGRAMMAROPTIONS = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_SRGS_W3C_SCRIPT: SPGRAMMAROPTIONS = 256i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_SRGS_STG_SCRIPT: SPGRAMMAROPTIONS = 512i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_SRGS_SCRIPT: SPGRAMMAROPTIONS = 778i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_FILE: SPGRAMMAROPTIONS = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_HTTP: SPGRAMMAROPTIONS = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_RES: SPGRAMMAROPTIONS = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_OBJECT: SPGRAMMAROPTIONS = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_DEFAULT: SPGRAMMAROPTIONS = 1019i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGO_ALL: SPGRAMMAROPTIONS = 1023i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPGRAMMARSTATE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGS_DISABLED: SPGRAMMARSTATE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGS_ENABLED: SPGRAMMARSTATE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPGS_EXCLUSIVE: SPGRAMMARSTATE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPGRAMMARWORDTYPE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWT_DISPLAY: SPGRAMMARWORDTYPE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWT_LEXICAL: SPGRAMMARWORDTYPE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWT_PRONUNCIATION: SPGRAMMARWORDTYPE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWT_LEXICAL_NO_SPECIAL_CHARS: SPGRAMMARWORDTYPE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPINTERFERENCE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_NONE: SPINTERFERENCE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_NOISE: SPINTERFERENCE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_NOSIGNAL: SPINTERFERENCE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_TOOLOUD: SPINTERFERENCE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_TOOQUIET: SPINTERFERENCE = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_TOOFAST: SPINTERFERENCE = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_TOOSLOW: SPINTERFERENCE = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_LATENCY_WARNING: SPINTERFERENCE = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_LATENCY_TRUNCATE_BEGIN: SPINTERFERENCE = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPINTERFERENCE_LATENCY_TRUNCATE_END: SPINTERFERENCE = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPLEXICONTYPE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_USER: SPLEXICONTYPE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_APP: SPLEXICONTYPE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_VENDORLEXICON: SPLEXICONTYPE = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_LETTERTOSOUND: SPLEXICONTYPE = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_MORPHOLOGY: SPLEXICONTYPE = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_RESERVED4: SPLEXICONTYPE = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_USER_SHORTCUT: SPLEXICONTYPE = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_RESERVED6: SPLEXICONTYPE = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_RESERVED7: SPLEXICONTYPE = 256i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_RESERVED8: SPLEXICONTYPE = 512i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_RESERVED9: SPLEXICONTYPE = 1024i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_RESERVED10: SPLEXICONTYPE = 2048i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE1: SPLEXICONTYPE = 4096i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE2: SPLEXICONTYPE = 8192i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE3: SPLEXICONTYPE = 16384i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE4: SPLEXICONTYPE = 32768i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE5: SPLEXICONTYPE = 65536i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE6: SPLEXICONTYPE = 131072i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE7: SPLEXICONTYPE = 262144i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE8: SPLEXICONTYPE = 524288i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE9: SPLEXICONTYPE = 1048576i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE10: SPLEXICONTYPE = 2097152i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE11: SPLEXICONTYPE = 4194304i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE12: SPLEXICONTYPE = 8388608i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE13: SPLEXICONTYPE = 16777216i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE14: SPLEXICONTYPE = 33554432i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE15: SPLEXICONTYPE = 67108864i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE16: SPLEXICONTYPE = 134217728i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE17: SPLEXICONTYPE = 268435456i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE18: SPLEXICONTYPE = 536870912i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE19: SPLEXICONTYPE = 1073741824i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eLEXTYPE_PRIVATE20: SPLEXICONTYPE = -2147483648i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPLOADOPTIONS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPLO_STATIC: SPLOADOPTIONS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPLO_DYNAMIC: SPLOADOPTIONS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPMATCHINGMODE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const AllWords: SPMATCHINGMODE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const Subsequence: SPMATCHINGMODE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const OrderedSubset: SPMATCHINGMODE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SubsequenceContentRequired: SPMATCHINGMODE = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const OrderedSubsetContentRequired: SPMATCHINGMODE = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPPARTOFSPEECH = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_NotOverriden: SPPARTOFSPEECH = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_Unknown: SPPARTOFSPEECH = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_Noun: SPPARTOFSPEECH = 4096i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_Verb: SPPARTOFSPEECH = 8192i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_Modifier: SPPARTOFSPEECH = 12288i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_Function: SPPARTOFSPEECH = 16384i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_Interjection: SPPARTOFSPEECH = 20480i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_Noncontent: SPPARTOFSPEECH = 24576i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_LMA: SPPARTOFSPEECH = 28672i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_SuppressWord: SPPARTOFSPEECH = 61440i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPPHRASEPROPERTYUNIONTYPE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPPUT_UNUSED: SPPHRASEPROPERTYUNIONTYPE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPPUT_ARRAY_INDEX: SPPHRASEPROPERTYUNIONTYPE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPPHRASERNG = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPR_ALL_ELEMENTS: SPPHRASERNG = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPPRONUNCIATIONFLAGS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const ePRONFLAG_USED: SPPRONUNCIATIONFLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPRECOEVENTFLAGS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREF_AutoPause: SPRECOEVENTFLAGS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREF_Emulated: SPRECOEVENTFLAGS = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREF_SMLTimeout: SPRECOEVENTFLAGS = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREF_ExtendableParse: SPRECOEVENTFLAGS = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREF_ReSent: SPRECOEVENTFLAGS = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREF_Hypothesis: SPRECOEVENTFLAGS = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPREF_FalseRecognition: SPRECOEVENTFLAGS = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPRECOSTATE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRST_INACTIVE: SPRECOSTATE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRST_ACTIVE: SPRECOSTATE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRST_ACTIVE_ALWAYS: SPRECOSTATE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRST_INACTIVE_WITH_PURGE: SPRECOSTATE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRST_NUM_STATES: SPRECOSTATE = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPRULESTATE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRS_INACTIVE: SPRULESTATE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRS_ACTIVE: SPRULESTATE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRS_ACTIVE_WITH_AUTO_PAUSE: SPRULESTATE = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRS_ACTIVE_USER_DELIMITED: SPRULESTATE = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPRUNSTATE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRS_DONE: SPRUNSTATE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPRS_IS_SPEAKING: SPRUNSTATE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPSEMANTICFORMAT = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSMF_SAPI_PROPERTIES: SPSEMANTICFORMAT = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSMF_SRGS_SEMANTICINTERPRETATION_MS: SPSEMANTICFORMAT = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSMF_SRGS_SAPIPROPERTIES: SPSEMANTICFORMAT = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSMF_UPS: SPSEMANTICFORMAT = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSMF_SRGS_SEMANTICINTERPRETATION_W3C: SPSEMANTICFORMAT = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPSHORTCUTTYPE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSHT_NotOverriden: SPSHORTCUTTYPE = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSHT_Unknown: SPSHORTCUTTYPE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSHT_EMAIL: SPSHORTCUTTYPE = 4096i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSHT_OTHER: SPSHORTCUTTYPE = 8192i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_RESERVED1: SPSHORTCUTTYPE = 12288i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_RESERVED2: SPSHORTCUTTYPE = 16384i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_RESERVED3: SPSHORTCUTTYPE = 20480i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPPS_RESERVED4: SPSHORTCUTTYPE = 61440i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPSTREAMFORMAT = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_Default: SPSTREAMFORMAT = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_NoAssignedFormat: SPSTREAMFORMAT = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_Text: SPSTREAMFORMAT = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_NonStandardFormat: SPSTREAMFORMAT = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ExtendedAudioFormat: SPSTREAMFORMAT = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_8kHz8BitMono: SPSTREAMFORMAT = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_8kHz8BitStereo: SPSTREAMFORMAT = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_8kHz16BitMono: SPSTREAMFORMAT = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_8kHz16BitStereo: SPSTREAMFORMAT = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_11kHz8BitMono: SPSTREAMFORMAT = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_11kHz8BitStereo: SPSTREAMFORMAT = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_11kHz16BitMono: SPSTREAMFORMAT = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_11kHz16BitStereo: SPSTREAMFORMAT = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_12kHz8BitMono: SPSTREAMFORMAT = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_12kHz8BitStereo: SPSTREAMFORMAT = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_12kHz16BitMono: SPSTREAMFORMAT = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_12kHz16BitStereo: SPSTREAMFORMAT = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_16kHz8BitMono: SPSTREAMFORMAT = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_16kHz8BitStereo: SPSTREAMFORMAT = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_16kHz16BitMono: SPSTREAMFORMAT = 18i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_16kHz16BitStereo: SPSTREAMFORMAT = 19i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_22kHz8BitMono: SPSTREAMFORMAT = 20i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_22kHz8BitStereo: SPSTREAMFORMAT = 21i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_22kHz16BitMono: SPSTREAMFORMAT = 22i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_22kHz16BitStereo: SPSTREAMFORMAT = 23i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_24kHz8BitMono: SPSTREAMFORMAT = 24i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_24kHz8BitStereo: SPSTREAMFORMAT = 25i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_24kHz16BitMono: SPSTREAMFORMAT = 26i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_24kHz16BitStereo: SPSTREAMFORMAT = 27i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_32kHz8BitMono: SPSTREAMFORMAT = 28i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_32kHz8BitStereo: SPSTREAMFORMAT = 29i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_32kHz16BitMono: SPSTREAMFORMAT = 30i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_32kHz16BitStereo: SPSTREAMFORMAT = 31i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_44kHz8BitMono: SPSTREAMFORMAT = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_44kHz8BitStereo: SPSTREAMFORMAT = 33i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_44kHz16BitMono: SPSTREAMFORMAT = 34i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_44kHz16BitStereo: SPSTREAMFORMAT = 35i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_48kHz8BitMono: SPSTREAMFORMAT = 36i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_48kHz8BitStereo: SPSTREAMFORMAT = 37i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_48kHz16BitMono: SPSTREAMFORMAT = 38i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_48kHz16BitStereo: SPSTREAMFORMAT = 39i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_TrueSpeech_8kHz1BitMono: SPSTREAMFORMAT = 40i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_ALaw_8kHzMono: SPSTREAMFORMAT = 41i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_ALaw_8kHzStereo: SPSTREAMFORMAT = 42i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_ALaw_11kHzMono: SPSTREAMFORMAT = 43i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_ALaw_11kHzStereo: SPSTREAMFORMAT = 44i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_ALaw_22kHzMono: SPSTREAMFORMAT = 45i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_ALaw_22kHzStereo: SPSTREAMFORMAT = 46i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_ALaw_44kHzMono: SPSTREAMFORMAT = 47i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_ALaw_44kHzStereo: SPSTREAMFORMAT = 48i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_uLaw_8kHzMono: SPSTREAMFORMAT = 49i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_uLaw_8kHzStereo: SPSTREAMFORMAT = 50i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_uLaw_11kHzMono: SPSTREAMFORMAT = 51i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_uLaw_11kHzStereo: SPSTREAMFORMAT = 52i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_uLaw_22kHzMono: SPSTREAMFORMAT = 53i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_uLaw_22kHzStereo: SPSTREAMFORMAT = 54i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_uLaw_44kHzMono: SPSTREAMFORMAT = 55i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_CCITT_uLaw_44kHzStereo: SPSTREAMFORMAT = 56i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ADPCM_8kHzMono: SPSTREAMFORMAT = 57i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ADPCM_8kHzStereo: SPSTREAMFORMAT = 58i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ADPCM_11kHzMono: SPSTREAMFORMAT = 59i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ADPCM_11kHzStereo: SPSTREAMFORMAT = 60i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ADPCM_22kHzMono: SPSTREAMFORMAT = 61i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ADPCM_22kHzStereo: SPSTREAMFORMAT = 62i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ADPCM_44kHzMono: SPSTREAMFORMAT = 63i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_ADPCM_44kHzStereo: SPSTREAMFORMAT = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_GSM610_8kHzMono: SPSTREAMFORMAT = 65i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_GSM610_11kHzMono: SPSTREAMFORMAT = 66i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_GSM610_22kHzMono: SPSTREAMFORMAT = 67i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_GSM610_44kHzMono: SPSTREAMFORMAT = 68i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSF_NUM_FORMATS: SPSTREAMFORMAT = 69i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPSTREAMFORMATTYPE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWF_INPUT: SPSTREAMFORMATTYPE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWF_SRENGINE: SPSTREAMFORMATTYPE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPVACTIONS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVA_Speak: SPVACTIONS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVA_Silence: SPVACTIONS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVA_Pronounce: SPVACTIONS = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVA_Bookmark: SPVACTIONS = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVA_SpellOut: SPVACTIONS = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVA_Section: SPVACTIONS = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVA_ParseUnknownTag: SPVACTIONS = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPVALUETYPE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_PROPERTY: SPVALUETYPE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_REPLACEMENT: SPVALUETYPE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_RULE: SPVALUETYPE = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_DISPLAYTEXT: SPVALUETYPE = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_LEXICALFORM: SPVALUETYPE = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_PRONUNCIATION: SPVALUETYPE = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_AUDIO: SPVALUETYPE = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_ALTERNATES: SPVALUETYPE = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPDF_ALL: SPVALUETYPE = 255i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPVFEATURE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVFEATURE_STRESSED: SPVFEATURE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVFEATURE_EMPHASIS: SPVFEATURE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPVISEMES = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_0: SPVISEMES = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_1: SPVISEMES = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_2: SPVISEMES = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_3: SPVISEMES = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_4: SPVISEMES = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_5: SPVISEMES = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_6: SPVISEMES = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_7: SPVISEMES = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_8: SPVISEMES = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_9: SPVISEMES = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_10: SPVISEMES = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_11: SPVISEMES = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_12: SPVISEMES = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_13: SPVISEMES = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_14: SPVISEMES = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_15: SPVISEMES = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_16: SPVISEMES = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_17: SPVISEMES = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_18: SPVISEMES = 18i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_19: SPVISEMES = 19i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_20: SPVISEMES = 20i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SP_VISEME_21: SPVISEMES = 21i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPVLIMITS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPMIN_VOLUME: SPVLIMITS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPMAX_VOLUME: SPVLIMITS = 100i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPMIN_RATE: SPVLIMITS = -10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPMAX_RATE: SPVLIMITS = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPVPRIORITY = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVPRI_NORMAL: SPVPRIORITY = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVPRI_ALERT: SPVPRIORITY = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPVPRI_OVER: SPVPRIORITY = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPWORDPRONOUNCEABLE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWP_UNKNOWN_WORD_UNPRONOUNCEABLE: SPWORDPRONOUNCEABLE = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWP_UNKNOWN_WORD_PRONOUNCEABLE: SPWORDPRONOUNCEABLE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPWP_KNOWN_WORD_PRONOUNCEABLE: SPWORDPRONOUNCEABLE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPWORDTYPE = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eWORDTYPE_ADDED: SPWORDTYPE = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const eWORDTYPE_DELETED: SPWORDTYPE = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SPXMLRESULTOPTIONS = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPXRO_SML: SPXMLRESULTOPTIONS = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPXRO_Alternates_SML: SPXMLRESULTOPTIONS = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechAudioFormatType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTDefault: SpeechAudioFormatType = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTNoAssignedFormat: SpeechAudioFormatType = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTText: SpeechAudioFormatType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTNonStandardFormat: SpeechAudioFormatType = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTExtendedAudioFormat: SpeechAudioFormatType = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT8kHz8BitMono: SpeechAudioFormatType = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT8kHz8BitStereo: SpeechAudioFormatType = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT8kHz16BitMono: SpeechAudioFormatType = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT8kHz16BitStereo: SpeechAudioFormatType = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT11kHz8BitMono: SpeechAudioFormatType = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT11kHz8BitStereo: SpeechAudioFormatType = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT11kHz16BitMono: SpeechAudioFormatType = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT11kHz16BitStereo: SpeechAudioFormatType = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT12kHz8BitMono: SpeechAudioFormatType = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT12kHz8BitStereo: SpeechAudioFormatType = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT12kHz16BitMono: SpeechAudioFormatType = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT12kHz16BitStereo: SpeechAudioFormatType = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT16kHz8BitMono: SpeechAudioFormatType = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT16kHz8BitStereo: SpeechAudioFormatType = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT16kHz16BitMono: SpeechAudioFormatType = 18i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT16kHz16BitStereo: SpeechAudioFormatType = 19i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT22kHz8BitMono: SpeechAudioFormatType = 20i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT22kHz8BitStereo: SpeechAudioFormatType = 21i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT22kHz16BitMono: SpeechAudioFormatType = 22i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT22kHz16BitStereo: SpeechAudioFormatType = 23i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT24kHz8BitMono: SpeechAudioFormatType = 24i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT24kHz8BitStereo: SpeechAudioFormatType = 25i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT24kHz16BitMono: SpeechAudioFormatType = 26i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT24kHz16BitStereo: SpeechAudioFormatType = 27i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT32kHz8BitMono: SpeechAudioFormatType = 28i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT32kHz8BitStereo: SpeechAudioFormatType = 29i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT32kHz16BitMono: SpeechAudioFormatType = 30i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT32kHz16BitStereo: SpeechAudioFormatType = 31i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT44kHz8BitMono: SpeechAudioFormatType = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT44kHz8BitStereo: SpeechAudioFormatType = 33i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT44kHz16BitMono: SpeechAudioFormatType = 34i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT44kHz16BitStereo: SpeechAudioFormatType = 35i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT48kHz8BitMono: SpeechAudioFormatType = 36i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT48kHz8BitStereo: SpeechAudioFormatType = 37i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT48kHz16BitMono: SpeechAudioFormatType = 38i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFT48kHz16BitStereo: SpeechAudioFormatType = 39i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTTrueSpeech_8kHz1BitMono: SpeechAudioFormatType = 40i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_ALaw_8kHzMono: SpeechAudioFormatType = 41i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_ALaw_8kHzStereo: SpeechAudioFormatType = 42i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_ALaw_11kHzMono: SpeechAudioFormatType = 43i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_ALaw_11kHzStereo: SpeechAudioFormatType = 44i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_ALaw_22kHzMono: SpeechAudioFormatType = 45i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_ALaw_22kHzStereo: SpeechAudioFormatType = 46i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_ALaw_44kHzMono: SpeechAudioFormatType = 47i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_ALaw_44kHzStereo: SpeechAudioFormatType = 48i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_uLaw_8kHzMono: SpeechAudioFormatType = 49i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_uLaw_8kHzStereo: SpeechAudioFormatType = 50i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_uLaw_11kHzMono: SpeechAudioFormatType = 51i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_uLaw_11kHzStereo: SpeechAudioFormatType = 52i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_uLaw_22kHzMono: SpeechAudioFormatType = 53i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_uLaw_22kHzStereo: SpeechAudioFormatType = 54i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_uLaw_44kHzMono: SpeechAudioFormatType = 55i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTCCITT_uLaw_44kHzStereo: SpeechAudioFormatType = 56i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTADPCM_8kHzMono: SpeechAudioFormatType = 57i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTADPCM_8kHzStereo: SpeechAudioFormatType = 58i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTADPCM_11kHzMono: SpeechAudioFormatType = 59i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTADPCM_11kHzStereo: SpeechAudioFormatType = 60i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTADPCM_22kHzMono: SpeechAudioFormatType = 61i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTADPCM_22kHzStereo: SpeechAudioFormatType = 62i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTADPCM_44kHzMono: SpeechAudioFormatType = 63i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTADPCM_44kHzStereo: SpeechAudioFormatType = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTGSM610_8kHzMono: SpeechAudioFormatType = 65i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTGSM610_11kHzMono: SpeechAudioFormatType = 66i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTGSM610_22kHzMono: SpeechAudioFormatType = 67i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SAFTGSM610_44kHzMono: SpeechAudioFormatType = 68i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechAudioState = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SASClosed: SpeechAudioState = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SASStop: SpeechAudioState = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SASPause: SpeechAudioState = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SASRun: SpeechAudioState = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechBookmarkOptions = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SBONone: SpeechBookmarkOptions = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SBOPause: SpeechBookmarkOptions = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechDataKeyLocation = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDKLDefaultLocation: SpeechDataKeyLocation = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDKLCurrentUser: SpeechDataKeyLocation = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDKLLocalMachine: SpeechDataKeyLocation = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDKLCurrentConfig: SpeechDataKeyLocation = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechDiscardType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTProperty: SpeechDiscardType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTReplacement: SpeechDiscardType = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTRule: SpeechDiscardType = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTDisplayText: SpeechDiscardType = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTLexicalForm: SpeechDiscardType = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTPronunciation: SpeechDiscardType = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTAudio: SpeechDiscardType = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTAlternates: SpeechDiscardType = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDTAll: SpeechDiscardType = 255i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechDisplayAttributes = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDA_No_Trailing_Space: SpeechDisplayAttributes = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDA_One_Trailing_Space: SpeechDisplayAttributes = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDA_Two_Trailing_Spaces: SpeechDisplayAttributes = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SDA_Consume_Leading_Spaces: SpeechDisplayAttributes = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechEmulationCompareFlags = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECFIgnoreCase: SpeechEmulationCompareFlags = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECFIgnoreKanaType: SpeechEmulationCompareFlags = 65536i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECFIgnoreWidth: SpeechEmulationCompareFlags = 131072i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECFNoSpecialChars: SpeechEmulationCompareFlags = 536870912i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECFEmulateResult: SpeechEmulationCompareFlags = 1073741824i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECFDefault: SpeechEmulationCompareFlags = 196609i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechEngineConfidence = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECLowConfidence: SpeechEngineConfidence = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECNormalConfidence: SpeechEngineConfidence = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SECHighConfidence: SpeechEngineConfidence = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechFormatType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SFTInput: SpeechFormatType = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SFTSREngine: SpeechFormatType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechGrammarRuleStateTransitionType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGRSTTEpsilon: SpeechGrammarRuleStateTransitionType = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGRSTTWord: SpeechGrammarRuleStateTransitionType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGRSTTRule: SpeechGrammarRuleStateTransitionType = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGRSTTDictation: SpeechGrammarRuleStateTransitionType = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGRSTTWildcard: SpeechGrammarRuleStateTransitionType = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGRSTTTextBuffer: SpeechGrammarRuleStateTransitionType = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechGrammarState = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGSEnabled: SpeechGrammarState = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGSDisabled: SpeechGrammarState = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGSExclusive: SpeechGrammarState = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechGrammarWordType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGDisplay: SpeechGrammarWordType = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGLexical: SpeechGrammarWordType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGPronounciation: SpeechGrammarWordType = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGLexicalNoSpecialChars: SpeechGrammarWordType = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechInterference = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SINone: SpeechInterference = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SINoise: SpeechInterference = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SINoSignal: SpeechInterference = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SITooLoud: SpeechInterference = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SITooQuiet: SpeechInterference = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SITooFast: SpeechInterference = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SITooSlow: SpeechInterference = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechLexiconType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SLTUser: SpeechLexiconType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SLTApp: SpeechLexiconType = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechLoadOption = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SLOStatic: SpeechLoadOption = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SLODynamic: SpeechLoadOption = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechPartOfSpeech = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSNotOverriden: SpeechPartOfSpeech = -1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSUnknown: SpeechPartOfSpeech = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSNoun: SpeechPartOfSpeech = 4096i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSVerb: SpeechPartOfSpeech = 8192i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSModifier: SpeechPartOfSpeech = 12288i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSFunction: SpeechPartOfSpeech = 16384i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSInterjection: SpeechPartOfSpeech = 20480i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSLMA: SpeechPartOfSpeech = 28672i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SPSSuppressWord: SpeechPartOfSpeech = 61440i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechRecoContextState = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRCS_Disabled: SpeechRecoContextState = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRCS_Enabled: SpeechRecoContextState = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechRecoEvents = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREStreamEnd: SpeechRecoEvents = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRESoundStart: SpeechRecoEvents = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRESoundEnd: SpeechRecoEvents = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREPhraseStart: SpeechRecoEvents = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRERecognition: SpeechRecoEvents = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREHypothesis: SpeechRecoEvents = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREBookmark: SpeechRecoEvents = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREPropertyNumChange: SpeechRecoEvents = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREPropertyStringChange: SpeechRecoEvents = 256i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREFalseRecognition: SpeechRecoEvents = 512i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREInterference: SpeechRecoEvents = 1024i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRERequestUI: SpeechRecoEvents = 2048i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREStateChange: SpeechRecoEvents = 4096i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREAdaptation: SpeechRecoEvents = 8192i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREStreamStart: SpeechRecoEvents = 16384i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRERecoOtherContext: SpeechRecoEvents = 32768i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREAudioLevel: SpeechRecoEvents = 65536i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREPrivate: SpeechRecoEvents = 262144i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SREAllEvents: SpeechRecoEvents = 393215i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechRecognitionType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRTStandard: SpeechRecognitionType = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRTAutopause: SpeechRecognitionType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRTEmulated: SpeechRecognitionType = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRTSMLTimeout: SpeechRecognitionType = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRTExtendableParse: SpeechRecognitionType = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRTReSent: SpeechRecognitionType = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechRecognizerState = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRSInactive: SpeechRecognizerState = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRSActive: SpeechRecognizerState = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRSActiveAlways: SpeechRecognizerState = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRSInactiveWithPurge: SpeechRecognizerState = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechRetainedAudioOptions = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRAONone: SpeechRetainedAudioOptions = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRAORetainAudio: SpeechRetainedAudioOptions = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechRuleAttributes = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRATopLevel: SpeechRuleAttributes = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRADefaultToActive: SpeechRuleAttributes = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRAExport: SpeechRuleAttributes = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRAImport: SpeechRuleAttributes = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRAInterpreter: SpeechRuleAttributes = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRADynamic: SpeechRuleAttributes = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRARoot: SpeechRuleAttributes = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechRuleState = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGDSInactive: SpeechRuleState = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGDSActive: SpeechRuleState = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGDSActiveWithAutoPause: SpeechRuleState = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SGDSActiveUserDelimited: SpeechRuleState = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechRunState = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRSEDone: SpeechRunState = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SRSEIsSpeaking: SpeechRunState = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechSpecialTransitionType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSTTWildcard: SpeechSpecialTransitionType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSTTDictation: SpeechSpecialTransitionType = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSTTTextBuffer: SpeechSpecialTransitionType = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechStreamFileMode = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSFMOpenForRead: SpeechStreamFileMode = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSFMOpenReadWrite: SpeechStreamFileMode = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSFMCreate: SpeechStreamFileMode = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSFMCreateForWrite: SpeechStreamFileMode = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechStreamSeekPositionType = u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSSPTRelativeToStart: SpeechStreamSeekPositionType = 0u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSSPTRelativeToCurrentPosition: SpeechStreamSeekPositionType = 1u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SSSPTRelativeToEnd: SpeechStreamSeekPositionType = 2u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechTokenContext = u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STCInprocServer: SpeechTokenContext = 1u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STCInprocHandler: SpeechTokenContext = 2u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STCLocalServer: SpeechTokenContext = 4u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STCRemoteServer: SpeechTokenContext = 16u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STCAll: SpeechTokenContext = 23u32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechTokenShellFolder = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STSF_AppData: SpeechTokenShellFolder = 26i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STSF_LocalAppData: SpeechTokenShellFolder = 28i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STSF_CommonAppData: SpeechTokenShellFolder = 35i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const STSF_FlagCreate: SpeechTokenShellFolder = 32768i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechVisemeFeature = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVF_None: SpeechVisemeFeature = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVF_Stressed: SpeechVisemeFeature = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVF_Emphasis: SpeechVisemeFeature = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechVisemeType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_0: SpeechVisemeType = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_1: SpeechVisemeType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_2: SpeechVisemeType = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_3: SpeechVisemeType = 3i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_4: SpeechVisemeType = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_5: SpeechVisemeType = 5i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_6: SpeechVisemeType = 6i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_7: SpeechVisemeType = 7i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_8: SpeechVisemeType = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_9: SpeechVisemeType = 9i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_10: SpeechVisemeType = 10i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_11: SpeechVisemeType = 11i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_12: SpeechVisemeType = 12i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_13: SpeechVisemeType = 13i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_14: SpeechVisemeType = 14i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_15: SpeechVisemeType = 15i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_16: SpeechVisemeType = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_17: SpeechVisemeType = 17i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_18: SpeechVisemeType = 18i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_19: SpeechVisemeType = 19i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_20: SpeechVisemeType = 20i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVP_21: SpeechVisemeType = 21i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechVoiceEvents = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEStartInputStream: SpeechVoiceEvents = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEEndInputStream: SpeechVoiceEvents = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEVoiceChange: SpeechVoiceEvents = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEBookmark: SpeechVoiceEvents = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEWordBoundary: SpeechVoiceEvents = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEPhoneme: SpeechVoiceEvents = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVESentenceBoundary: SpeechVoiceEvents = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEViseme: SpeechVoiceEvents = 256i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEAudioLevel: SpeechVoiceEvents = 512i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEPrivate: SpeechVoiceEvents = 32768i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVEAllEvents: SpeechVoiceEvents = 33790i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechVoicePriority = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVPNormal: SpeechVoicePriority = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVPAlert: SpeechVoicePriority = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVPOver: SpeechVoicePriority = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechVoiceSpeakFlags = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFDefault: SpeechVoiceSpeakFlags = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFlagsAsync: SpeechVoiceSpeakFlags = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFPurgeBeforeSpeak: SpeechVoiceSpeakFlags = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFIsFilename: SpeechVoiceSpeakFlags = 4i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFIsXML: SpeechVoiceSpeakFlags = 8i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFIsNotXML: SpeechVoiceSpeakFlags = 16i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFPersistXML: SpeechVoiceSpeakFlags = 32i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFNLPSpeakPunc: SpeechVoiceSpeakFlags = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFParseSapi: SpeechVoiceSpeakFlags = 128i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFParseSsml: SpeechVoiceSpeakFlags = 256i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFParseAutodetect: SpeechVoiceSpeakFlags = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFNLPMask: SpeechVoiceSpeakFlags = 64i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFParseMask: SpeechVoiceSpeakFlags = 384i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFVoiceMask: SpeechVoiceSpeakFlags = 511i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SVSFUnusedFlags: SpeechVoiceSpeakFlags = -512i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechWordPronounceable = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SWPUnknownWordUnpronounceable: SpeechWordPronounceable = 0i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SWPUnknownWordPronounceable: SpeechWordPronounceable = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SWPKnownWordPronounceable: SpeechWordPronounceable = 2i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub type SpeechWordType = i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SWTAdded: SpeechWordType = 1i32;
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub const SWTDeleted: SpeechWordType = 2i32;
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPAUDIOBUFFERINFO {
    pub ulMsMinNotification: u32,
    pub ulMsBufferSize: u32,
    pub ulMsEventBias: u32,
}
impl ::core::marker::Copy for SPAUDIOBUFFERINFO {}
impl ::core::clone::Clone for SPAUDIOBUFFERINFO {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPAUDIOSTATUS {
    pub cbFreeBuffSpace: i32,
    pub cbNonBlockingIO: u32,
    pub State: SPAUDIOSTATE,
    pub CurSeekPos: u64,
    pub CurDevicePos: u64,
    pub dwAudioLevel: u32,
    pub dwReserved2: u32,
}
impl ::core::marker::Copy for SPAUDIOSTATUS {}
impl ::core::clone::Clone for SPAUDIOSTATUS {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPBINARYGRAMMAR {
    pub ulTotalSerializedSize: u32,
}
impl ::core::marker::Copy for SPBINARYGRAMMAR {}
impl ::core::clone::Clone for SPBINARYGRAMMAR {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPDISPLAYPHRASE {
    pub ulNumTokens: u32,
    pub pTokens: *mut SPDISPLAYTOKEN,
}
impl ::core::marker::Copy for SPDISPLAYPHRASE {}
impl ::core::clone::Clone for SPDISPLAYPHRASE {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPDISPLAYTOKEN {
    pub pszLexical: ::windows_sys::core::PCWSTR,
    pub pszDisplay: ::windows_sys::core::PCWSTR,
    pub bDisplayAttributes: u8,
}
impl ::core::marker::Copy for SPDISPLAYTOKEN {}
impl ::core::clone::Clone for SPDISPLAYTOKEN {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct SPEVENT {
    pub _bitfield: i32,
    pub ulStreamNum: u32,
    pub ullAudioStreamOffset: u64,
    pub wParam: super::super::Foundation::WPARAM,
    pub lParam: super::super::Foundation::LPARAM,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for SPEVENT {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for SPEVENT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct SPEVENTEX {
    pub _bitfield: i32,
    pub ulStreamNum: u32,
    pub ullAudioStreamOffset: u64,
    pub wParam: super::super::Foundation::WPARAM,
    pub lParam: super::super::Foundation::LPARAM,
    pub ullAudioTimeOffset: u64,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for SPEVENTEX {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for SPEVENTEX {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPEVENTSOURCEINFO {
    pub ullEventInterest: u64,
    pub ullQueuedInterest: u64,
    pub ulCount: u32,
}
impl ::core::marker::Copy for SPEVENTSOURCEINFO {}
impl ::core::clone::Clone for SPEVENTSOURCEINFO {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPNORMALIZATIONLIST {
    pub ulSize: u32,
    pub ppszzNormalizedList: *mut *mut u16,
}
impl ::core::marker::Copy for SPNORMALIZATIONLIST {}
impl ::core::clone::Clone for SPNORMALIZATIONLIST {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
pub struct SPPHRASE {
    pub Base: SPPHRASE_50,
    pub pSML: ::windows_sys::core::PWSTR,
    pub pSemanticErrorInfo: *mut SPSEMANTICERRORINFO,
}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::marker::Copy for SPPHRASE {}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::clone::Clone for SPPHRASE {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPPHRASEELEMENT {
    pub ulAudioTimeOffset: u32,
    pub ulAudioSizeTime: u32,
    pub ulAudioStreamOffset: u32,
    pub ulAudioSizeBytes: u32,
    pub ulRetainedStreamOffset: u32,
    pub ulRetainedSizeBytes: u32,
    pub pszDisplayText: ::windows_sys::core::PCWSTR,
    pub pszLexicalForm: ::windows_sys::core::PCWSTR,
    pub pszPronunciation: *const u16,
    pub bDisplayAttributes: u8,
    pub RequiredConfidence: i8,
    pub ActualConfidence: i8,
    pub Reserved: u8,
    pub SREngineConfidence: f32,
}
impl ::core::marker::Copy for SPPHRASEELEMENT {}
impl ::core::clone::Clone for SPPHRASEELEMENT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
pub struct SPPHRASEPROPERTY {
    pub pszName: ::windows_sys::core::PCWSTR,
    pub Anonymous: SPPHRASEPROPERTY_0,
    pub pszValue: ::windows_sys::core::PCWSTR,
    pub vValue: super::super::System::Com::VARIANT,
    pub ulFirstElement: u32,
    pub ulCountOfElements: u32,
    pub pNextSibling: *const SPPHRASEPROPERTY,
    pub pFirstChild: *const SPPHRASEPROPERTY,
    pub SREngineConfidence: f32,
    pub Confidence: i8,
}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::marker::Copy for SPPHRASEPROPERTY {}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::clone::Clone for SPPHRASEPROPERTY {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
pub union SPPHRASEPROPERTY_0 {
    pub ulId: u32,
    pub Anonymous: SPPHRASEPROPERTY_0_0,
}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::marker::Copy for SPPHRASEPROPERTY_0 {}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::clone::Clone for SPPHRASEPROPERTY_0 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
pub struct SPPHRASEPROPERTY_0_0 {
    pub bType: u8,
    pub bReserved: u8,
    pub usArrayIndex: u16,
}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::marker::Copy for SPPHRASEPROPERTY_0_0 {}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::clone::Clone for SPPHRASEPROPERTY_0_0 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPPHRASEREPLACEMENT {
    pub bDisplayAttributes: u8,
    pub pszReplacementText: ::windows_sys::core::PCWSTR,
    pub ulFirstElement: u32,
    pub ulCountOfElements: u32,
}
impl ::core::marker::Copy for SPPHRASEREPLACEMENT {}
impl ::core::clone::Clone for SPPHRASEREPLACEMENT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPPHRASERULE {
    pub pszName: ::windows_sys::core::PCWSTR,
    pub ulId: u32,
    pub ulFirstElement: u32,
    pub ulCountOfElements: u32,
    pub pNextSibling: *const SPPHRASERULE,
    pub pFirstChild: *const SPPHRASERULE,
    pub SREngineConfidence: f32,
    pub Confidence: i8,
}
impl ::core::marker::Copy for SPPHRASERULE {}
impl ::core::clone::Clone for SPPHRASERULE {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
pub struct SPPHRASE_50 {
    pub cbSize: u32,
    pub LangID: u16,
    pub wHomophoneGroupId: u16,
    pub ullGrammarID: u64,
    pub ftStartTime: u64,
    pub ullAudioStreamPosition: u64,
    pub ulAudioSizeBytes: u32,
    pub ulRetainedSizeBytes: u32,
    pub ulAudioSizeTime: u32,
    pub Rule: SPPHRASERULE,
    pub pProperties: *const SPPHRASEPROPERTY,
    pub pElements: *const SPPHRASEELEMENT,
    pub cReplacements: u32,
    pub pReplacements: *const SPPHRASEREPLACEMENT,
    pub SREngineID: ::windows_sys::core::GUID,
    pub ulSREnginePrivateDataSize: u32,
    pub pSREnginePrivateData: *const u8,
}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::marker::Copy for SPPHRASE_50 {}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::clone::Clone for SPPHRASE_50 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`, `\"Win32_System_Com\"`, `\"Win32_System_Ole\"`*"]
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
pub struct SPPROPERTYINFO {
    pub pszName: ::windows_sys::core::PCWSTR,
    pub ulId: u32,
    pub pszValue: ::windows_sys::core::PCWSTR,
    pub vValue: super::super::System::Com::VARIANT,
}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::marker::Copy for SPPROPERTYINFO {}
#[cfg(all(feature = "Win32_Foundation", feature = "Win32_System_Com", feature = "Win32_System_Ole"))]
impl ::core::clone::Clone for SPPROPERTYINFO {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPRECOCONTEXTSTATUS {
    pub eInterference: SPINTERFERENCE,
    pub szRequestTypeOfUI: [u16; 255],
    pub dwReserved1: u32,
    pub dwReserved2: u32,
}
impl ::core::marker::Copy for SPRECOCONTEXTSTATUS {}
impl ::core::clone::Clone for SPRECOCONTEXTSTATUS {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPRECOGNIZERSTATUS {
    pub AudioStatus: SPAUDIOSTATUS,
    pub ullRecognitionStreamPos: u64,
    pub ulStreamNumber: u32,
    pub ulNumActive: u32,
    pub clsidEngine: ::windows_sys::core::GUID,
    pub cLangIDs: u32,
    pub aLangID: [u16; 20],
    pub ullRecognitionStreamTime: u64,
}
impl ::core::marker::Copy for SPRECOGNIZERSTATUS {}
impl ::core::clone::Clone for SPRECOGNIZERSTATUS {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub struct SPRECORESULTTIMES {
    pub ftStreamTime: super::super::Foundation::FILETIME,
    pub ullLength: u64,
    pub dwTickCount: u32,
    pub ullStart: u64,
}
#[cfg(feature = "Win32_Foundation")]
impl ::core::marker::Copy for SPRECORESULTTIMES {}
#[cfg(feature = "Win32_Foundation")]
impl ::core::clone::Clone for SPRECORESULTTIMES {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPRULE {
    pub pszRuleName: ::windows_sys::core::PCWSTR,
    pub ulRuleId: u32,
    pub dwAttributes: u32,
}
impl ::core::marker::Copy for SPRULE {}
impl ::core::clone::Clone for SPRULE {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPSEMANTICERRORINFO {
    pub ulLineNumber: u32,
    pub pszScriptLine: ::windows_sys::core::PWSTR,
    pub pszSource: ::windows_sys::core::PWSTR,
    pub pszDescription: ::windows_sys::core::PWSTR,
    pub hrResultCode: ::windows_sys::core::HRESULT,
}
impl ::core::marker::Copy for SPSEMANTICERRORINFO {}
impl ::core::clone::Clone for SPSEMANTICERRORINFO {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPSERIALIZEDEVENT {
    pub _bitfield: i32,
    pub ulStreamNum: u32,
    pub ullAudioStreamOffset: u64,
    pub SerializedwParam: u32,
    pub SerializedlParam: i32,
}
impl ::core::marker::Copy for SPSERIALIZEDEVENT {}
impl ::core::clone::Clone for SPSERIALIZEDEVENT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPSERIALIZEDEVENT64 {
    pub _bitfield: i32,
    pub ulStreamNum: u32,
    pub ullAudioStreamOffset: u64,
    pub SerializedwParam: u64,
    pub SerializedlParam: i64,
}
impl ::core::marker::Copy for SPSERIALIZEDEVENT64 {}
impl ::core::clone::Clone for SPSERIALIZEDEVENT64 {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPSERIALIZEDPHRASE {
    pub ulSerializedSize: u32,
}
impl ::core::marker::Copy for SPSERIALIZEDPHRASE {}
impl ::core::clone::Clone for SPSERIALIZEDPHRASE {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPSERIALIZEDRESULT {
    pub ulSerializedSize: u32,
}
impl ::core::marker::Copy for SPSERIALIZEDRESULT {}
impl ::core::clone::Clone for SPSERIALIZEDRESULT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPSHORTCUTPAIR {
    pub pNextSHORTCUTPAIR: *mut SPSHORTCUTPAIR,
    pub LangID: u16,
    pub shType: SPSHORTCUTTYPE,
    pub pszDisplay: ::windows_sys::core::PWSTR,
    pub pszSpoken: ::windows_sys::core::PWSTR,
}
impl ::core::marker::Copy for SPSHORTCUTPAIR {}
impl ::core::clone::Clone for SPSHORTCUTPAIR {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPSHORTCUTPAIRLIST {
    pub ulSize: u32,
    pub pvBuffer: *mut u8,
    pub pFirstShortcutPair: *mut SPSHORTCUTPAIR,
}
impl ::core::marker::Copy for SPSHORTCUTPAIRLIST {}
impl ::core::clone::Clone for SPSHORTCUTPAIRLIST {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPSTATEHANDLE__ {
    pub unused: i32,
}
impl ::core::marker::Copy for SPSTATEHANDLE__ {}
impl ::core::clone::Clone for SPSTATEHANDLE__ {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPTEXTSELECTIONINFO {
    pub ulStartActiveOffset: u32,
    pub cchActiveChars: u32,
    pub ulStartSelection: u32,
    pub cchSelection: u32,
}
impl ::core::marker::Copy for SPTEXTSELECTIONINFO {}
impl ::core::clone::Clone for SPTEXTSELECTIONINFO {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPVCONTEXT {
    pub pCategory: ::windows_sys::core::PCWSTR,
    pub pBefore: ::windows_sys::core::PCWSTR,
    pub pAfter: ::windows_sys::core::PCWSTR,
}
impl ::core::marker::Copy for SPVCONTEXT {}
impl ::core::clone::Clone for SPVCONTEXT {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPVOICESTATUS {
    pub ulCurrentStream: u32,
    pub ulLastStreamQueued: u32,
    pub hrLastResult: ::windows_sys::core::HRESULT,
    pub dwRunningState: u32,
    pub ulInputWordPos: u32,
    pub ulInputWordLen: u32,
    pub ulInputSentPos: u32,
    pub ulInputSentLen: u32,
    pub lBookmarkId: i32,
    pub PhonemeId: u16,
    pub VisemeId: SPVISEMES,
    pub dwReserved1: u32,
    pub dwReserved2: u32,
}
impl ::core::marker::Copy for SPVOICESTATUS {}
impl ::core::clone::Clone for SPVOICESTATUS {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPVPITCH {
    pub MiddleAdj: i32,
    pub RangeAdj: i32,
}
impl ::core::marker::Copy for SPVPITCH {}
impl ::core::clone::Clone for SPVPITCH {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPVSTATE {
    pub eAction: SPVACTIONS,
    pub LangID: u16,
    pub wReserved: u16,
    pub EmphAdj: i32,
    pub RateAdj: i32,
    pub Volume: u32,
    pub PitchAdj: SPVPITCH,
    pub SilenceMSecs: u32,
    pub pPhoneIds: *mut u16,
    pub ePartOfSpeech: SPPARTOFSPEECH,
    pub Context: SPVCONTEXT,
}
impl ::core::marker::Copy for SPVSTATE {}
impl ::core::clone::Clone for SPVSTATE {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPWORD {
    pub pNextWord: *mut SPWORD,
    pub LangID: u16,
    pub wReserved: u16,
    pub eWordType: SPWORDTYPE,
    pub pszWord: ::windows_sys::core::PWSTR,
    pub pFirstWordPronunciation: *mut SPWORDPRONUNCIATION,
}
impl ::core::marker::Copy for SPWORD {}
impl ::core::clone::Clone for SPWORD {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPWORDLIST {
    pub ulSize: u32,
    pub pvBuffer: *mut u8,
    pub pFirstWord: *mut SPWORD,
}
impl ::core::marker::Copy for SPWORDLIST {}
impl ::core::clone::Clone for SPWORDLIST {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPWORDPRONUNCIATION {
    pub pNextWordPronunciation: *mut SPWORDPRONUNCIATION,
    pub eLexiconType: SPLEXICONTYPE,
    pub LangID: u16,
    pub wPronunciationFlags: u16,
    pub ePartOfSpeech: SPPARTOFSPEECH,
    pub szPronunciation: [u16; 1],
}
impl ::core::marker::Copy for SPWORDPRONUNCIATION {}
impl ::core::clone::Clone for SPWORDPRONUNCIATION {
    fn clone(&self) -> Self {
        *self
    }
}
#[repr(C)]
#[doc = "*Required features: `\"Win32_Media_Speech\"`*"]
pub struct SPWORDPRONUNCIATIONLIST {
    pub ulSize: u32,
    pub pvBuffer: *mut u8,
    pub pFirstWordPronunciation: *mut SPWORDPRONUNCIATION,
}
impl ::core::marker::Copy for SPWORDPRONUNCIATIONLIST {}
impl ::core::clone::Clone for SPWORDPRONUNCIATIONLIST {
    fn clone(&self) -> Self {
        *self
    }
}
#[doc = "*Required features: `\"Win32_Media_Speech\"`, `\"Win32_Foundation\"`*"]
#[cfg(feature = "Win32_Foundation")]
pub type SPNOTIFYCALLBACK = ::core::option::Option<unsafe extern "system" fn(wparam: super::super::Foundation::WPARAM, lparam: super::super::Foundation::LPARAM) -> ()>;
